==> spell-0.25.3-py2.py3-none-any.whl: spell/cli/utils/eks_cluster_templates.py <==
eks_cluster_autoscaler_yaml_template = """
---
apiVersion: v1
kind: ServiceAccount
metadata:
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
  name: cluster-autoscaler
  namespace: kube-system
---
apiVersion: rbac.authorization.k8s.io/v1
kind: ClusterRole
metadata:
  name: cluster-autoscaler
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
rules:
- apiGroups: [""]
  resources: ["events","endpoints"]
  verbs: ["create", "patch"]
- apiGroups: [""]
  resources: ["pods/eviction"]
  verbs: ["create"]
- apiGroups: [""]
  resources: ["pods/status"]
  verbs: ["update"]
- apiGroups: [""]
  resources: ["endpoints"]
  resourceNames: ["cluster-autoscaler"]
  verbs: ["get","update"]
- apiGroups: [""]
  resources: ["nodes"]
  verbs: ["watch","list","get","update"]
- apiGroups: [""]
  resources: ["pods","services","replicationcontrollers","persistentvolumeclaims","persistentvolumes"]
  verbs: ["watch","list","get"]
- apiGroups: ["extensions"]
  resources: ["replicasets","daemonsets"]
  verbs: ["watch","list","get"]
- apiGroups: ["policy"]
  resources: ["poddisruptionbudgets"]
  verbs: ["watch","list"]
- apiGroups: ["apps"]
  resources: ["statefulsets", "replicasets"]
  verbs: ["watch","list","get"]
- apiGroups: ["storage.k8s.io"]
  resources: ["storageclasses"]
  verbs: ["watch","list","get"]

---
apiVersion: rbac.authorization.k8s.io/v1
kind: Role
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
rules:
- apiGroups: [""]
  resources: ["configmaps"]
  verbs: ["create"]
- apiGroups: [""]
  resources: ["configmaps"]
  resourceNames: ["cluster-autoscaler-status"]
  verbs: ["delete","get","update"]

---
apiVersion: rbac.authorization.k8s.io/v1
kind: ClusterRoleBinding
metadata:
  name: cluster-autoscaler
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: ClusterRole
  name: cluster-autoscaler
subjects:
  - kind: ServiceAccount
    name: cluster-autoscaler
    namespace: kube-system

---
apiVersion: rbac.authorization.k8s.io/v1
kind: RoleBinding
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: Role
  name: cluster-autoscaler
subjects:
  - kind: ServiceAccount
    name: cluster-autoscaler
    namespace: kube-system

---
apiVersion: apps/v1
kind: Deployment
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    app: cluster-autoscaler
spec:
  replicas: 1
  selector:
    matchLabels:
      app: cluster-autoscaler
  template:
    metadata:
      labels:
        app: cluster-autoscaler
    spec:
      serviceAccountName: cluster-autoscaler
      containers:
        - image: k8s.gcr.io/cluster-autoscaler:v1.3.6
          name: cluster-autoscaler
          resources:
            limits:
              cpu: 100m
              memory: 300Mi
            requests:
              cpu: 100m
              memory: 300Mi
          command:
            - ./cluster-autoscaler
            - --v=4
            - --stderrthreshold=info
            - --cloud-provider=aws
            - --skip-nodes-with-local-storage=false
            - --nodes={}:{}:{}
          env:
            - name: AWS_REGION
              value: us-west-2
          volumeMounts:
            - name: ssl-certs
              mountPath: /etc/ssl/certs/ca-bundle.crt
              readOnly: true
          imagePullPolicy: "Always"
      volumes:
        - name: ssl-certs
          hostPath:
            path: "/etc/ssl/certs/ca-bundle.crt"
"""

eks_cluster_aws_auth_string = """- rolearn: arn:aws:iam::002219003547:role/nodes.prod.spell
  username: system:node:{{EC2PrivateDNSName}}
  groups:
  - system:masters
"""

eks_cluster_statsd_sink_yaml = """apiVersion: v1
kind: ConfigMap
metadata:
  name: nginx-graphite-conf
  labels:
    service: statsd-sink
data:
  nginx-graphite-conf: |-
    server {
      listen 81;
      root /opt/graphite/webapp/content;
      index index.html;

      auth_basic           "Spell Metrics - Auth Required";
      auth_basic_user_file /etc/nginx/htpasswd;

      location /media {
        # django admin static files
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/media/;
      }

      location /admin/auth/admin {
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/static/admin;
      }

      location /admin/auth/user/admin {
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/static/admin;
      }

      location / {
        # checks for static file, if not found proxy to app
        try_files \$uri @app;
      }

      location @app {
        include fastcgi_params;
        fastcgi_split_path_info ^()(.*)$;
        fastcgi_pass 127.0.0.1:8080;
        add_header 'Access-Control-Allow-Origin' '*';
        add_header 'Access-Control-Allow-Methods' 'GET, POST, OPTIONS';
        add_header 'Access-Control-Allow-Headers' 'Authorization, Content-Type';
        add_header 'Access-Control-Allow-Credentials' 'true';
      }
    }
---
apiVersion: apps/v1beta1
kind: StatefulSet
metadata:
  labels:
    service: statsd-sink
  name: statsd-sink
spec:
  serviceName: statsd-sink
  selector:
    matchLabels:
      service: statsd-sink
  replicas: 1
  template:
    metadata:
      labels:
        service: statsd-sink
    spec:
      containers:
      - image: hopsoft/graphite-statsd:v0.9.15-phusion0.9.19
        imagePullPolicy: Always
        name: statsd-sink
        ports:
        - containerPort: 8125
          name: metrics-port
          protocol: UDP
        - containerPort: 81
          name: graphite-www
          protocol: TCP
        volumeMounts:
        - name: graphite-storage
          mountPath: /opt/graphite/storage
          subPath: storage
        - name: nginx-graphite-auth-pwd
          mountPath: /etc/nginx/htpasswd
          subPath: htpasswd
          readOnly: true
        - name: nginx-graphite-conf
          mountPath: /etc/nginx/sites-enabled/graphite-statsd.conf
          subPath: graphite-statsd.conf
          readOnly: true
      volumes:
        - name: nginx-graphite-auth-pwd
          secret:
            secretName: nginx-graphite-auth-pwd
            items:
            - key: nginx-graphite-auth-pwd
              path: htpasswd
        - name: nginx-graphite-conf
          configMap:
            name: nginx-graphite-conf
            items:
            - key: nginx-graphite-conf
              path: graphite-statsd.conf
  volumeClaimTemplates:
  - metadata:
      name: graphite-storage
    spec:
      accessModes: [ "ReadWriteOnce" ]
      resources:
        requests:
          storage: 50Gi
---
apiVersion: v1
kind: Service
metadata:
  labels:
    service: statsd-sink
  name: statsd-sink
spec:
  ports:
  - name: statsd-metrics
    port: 8125
    protocol: UDP
    targetPort: 8125
  selector:
    service: statsd-sink
  type: ClusterIP
  clusterIP: None
---
apiVersion: v1
kind: Service
metadata:
  labels:
    service: statsd-sink-graphite
  name: statsd-sink-graphite
  annotations:
    service.beta.kubernetes.io/aws-load-balancer-backend-protocol: http
    service.beta.kubernetes.io/aws-load-balancer-ssl-ports: "443"
    service.beta.kubernetes.io/aws-load-balancer-ssl-cert: |
      arn:aws:acm:us-west-2:002219003547:certificate/d71ffa58-4723-425e-8cbe-fed3a7a3f6b2
    service.beta.kubernetes.io/aws-load-balancer-cross-zone-load-balancing-enabled: "true"
spec:
  ports:
  - name: graphite-www
    port: 443
    protocol: TCP
    targetPort: 81
  selector:
    service: statsd-sink
  type: LoadBalancer
"""

eks_cluster_ambassador_yaml = """
---
apiVersion: v1
kind: Service
metadata:
  labels:
    app: ambassador
    stack: serving
  name: ambassador
  annotations:
    service.beta.kubernetes.io/aws-load-balancer-backend-protocol: http
    service.beta.kubernetes.io/aws-load-balancer-ssl-ports: "443"
    service.beta.kubernetes.io/aws-load-balancer-ssl-cert: |
      arn:aws:acm:us-west-2:002219003547:certificate/d71ffa58-4723-425e-8cbe-fed3a7a3f6b2
    service.beta.kubernetes.io/aws-load-balancer-cross-zone-load-balancing-enabled: "true"
    getambassador.io/config: |
      ---
      apiVersion: ambassador/v0
      kind: Module
      name: ambassador
      config:
        x_forwarded_proto_redirect: true
      ---
      apiVersion: ambassador/v0
      kind:  AuthService
      name:  authentication
      auth_service: "https://api.spell.run"
      path_prefix: "/model_server_auth"
spec:
  ports:
  - name: https
    port: 443
    targetPort: 80
  selector:
    app: ambassador
    stack: serving
  type: LoadBalancer
---
apiVersion: v1
kind: Service
metadata:
  labels:
    app: ambassador-admin
    stack: serving
  name: ambassador-admin
spec:
  ports:
  - name: ambassador-admin
    port: 8877
    targetPort: 8877
  selector:
    app: ambassador
    stack: serving
  type: ClusterIP
---
apiVersion: v1
kind: ServiceAccount
metadata:
  name: ambassador
---
apiVersion: apps/v1
kind: Deployment
metadata:
  labels:
    app: ambassador
    stack: serving
  name: ambassador
spec:
  replicas: 2
  selector:
    matchLabels:
      app: ambassador
      stack: serving
  template:
    metadata:
      labels:
        app: ambassador
        stack: serving
    spec:
      containers:
      - env:
        - name: AMBASSADOR_NAMESPACE
          valueFrom:
            fieldRef:
              apiVersion: v1
              fieldPath: metadata.namespace
        - name: AMBASSADOR_SINGLE_NAMESPACE
          value: "true"
        - name: STATSD_ENABLED
          value: "true"
        image: quay.io/datawire/ambassador:0.40.1
        livenessProbe:
          httpGet:
            path: /ambassador/v0/check_alive
            port: 8877
          initialDelaySeconds: 30
          periodSeconds: 30
        name: ambassador
        readinessProbe:
          httpGet:
            path: /ambassador/v0/check_ready
            port: 8877
          initialDelaySeconds: 30
          periodSeconds: 30
        resources:
          limits:
            cpu: 1
            memory: 400Mi
          requests:
            cpu: 200m
            memory: 100Mi
      restartPolicy: Always
      serviceAccountName: ambassador
---
apiVersion: rbac.authorization.k8s.io/v1
kind: Role
metadata:
  name: ambassador
rules:
- apiGroups:
  - ""
  resources:
  - services
  verbs:
  - get
  - list
  - watch
- apiGroups:
  - ""
  resources:
  - configmaps
  verbs:
  - create
  - update
  - patch
  - get
  - list
  - watch
- apiGroups:
  - ""
  resources:
  - secrets
  verbs:
  - get
  - list
  - watch
---
apiVersion: rbac.authorization.k8s.io/v1
kind: RoleBinding
metadata:
  name: ambassador
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: Role
  name: ambassador
subjects:
- kind: ServiceAccount
  name: ambassador
"""


def generate_eks_cluster_autoscaler_yaml(min_nodes, max_nodes, asg_name):
    return eks_cluster_autoscaler_yaml_template.format(min_nodes, max_nodes, asg_name)

==> spell-0.25.5-py2.py3-none-any.whl: spell/cli/utils/eks_cluster_templates.py <==
eks_cluster_autoscaler_yaml_template = """
---
apiVersion: v1
kind: ServiceAccount
metadata:
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
  name: cluster-autoscaler
  namespace: kube-system
---
apiVersion: rbac.authorization.k8s.io/v1
kind: ClusterRole
metadata:
  name: cluster-autoscaler
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
rules:
- apiGroups: [""]
  resources: ["events","endpoints"]
  verbs: ["create", "patch"]
- apiGroups: [""]
  resources: ["pods/eviction"]
  verbs: ["create"]
- apiGroups: [""]
  resources: ["pods/status"]
  verbs: ["update"]
- apiGroups: [""]
  resources: ["endpoints"]
  resourceNames: ["cluster-autoscaler"]
  verbs: ["get","update"]
- apiGroups: [""]
  resources: ["nodes"]
  verbs: ["watch","list","get","update"]
- apiGroups: [""]
  resources: ["pods","services","replicationcontrollers","persistentvolumeclaims","persistentvolumes"]
  verbs: ["watch","list","get"]
- apiGroups: ["extensions"]
  resources: ["replicasets","daemonsets"]
  verbs: ["watch","list","get"]
- apiGroups: ["policy"]
  resources: ["poddisruptionbudgets"]
  verbs: ["watch","list"]
- apiGroups: ["apps"]
  resources: ["statefulsets", "replicasets"]
  verbs: ["watch","list","get"]
- apiGroups: ["storage.k8s.io"]
  resources: ["storageclasses"]
  verbs: ["watch","list","get"]

---
apiVersion: rbac.authorization.k8s.io/v1
kind: Role
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
rules:
- apiGroups: [""]
  resources: ["configmaps"]
  verbs: ["create"]
- apiGroups: [""]
  resources: ["configmaps"]
  resourceNames: ["cluster-autoscaler-status"]
  verbs: ["delete","get","update"]

---
apiVersion: rbac.authorization.k8s.io/v1
kind: ClusterRoleBinding
metadata:
  name: cluster-autoscaler
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: ClusterRole
  name: cluster-autoscaler
subjects:
  - kind: ServiceAccount
    name: cluster-autoscaler
    namespace: kube-system

---
apiVersion: rbac.authorization.k8s.io/v1
kind: RoleBinding
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    k8s-addon: cluster-autoscaler.addons.k8s.io
    k8s-app: cluster-autoscaler
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: Role
  name: cluster-autoscaler
subjects:
  - kind: ServiceAccount
    name: cluster-autoscaler
    namespace: kube-system

---
apiVersion: apps/v1
kind: Deployment
metadata:
  name: cluster-autoscaler
  namespace: kube-system
  labels:
    app: cluster-autoscaler
spec:
  replicas: 1
  selector:
    matchLabels:
      app: cluster-autoscaler
  template:
    metadata:
      labels:
        app: cluster-autoscaler
    spec:
      serviceAccountName: cluster-autoscaler
      containers:
        - image: k8s.gcr.io/cluster-autoscaler:v1.3.6
          name: cluster-autoscaler
          resources:
            limits:
              cpu: 100m
              memory: 300Mi
            requests:
              cpu: 100m
              memory: 300Mi
          command:
            - ./cluster-autoscaler
            - --v=4
            - --stderrthreshold=info
            - --cloud-provider=aws
            - --skip-nodes-with-local-storage=false
            - --nodes={}:{}:{}
          env:
            - name: AWS_REGION
              value: us-west-2
          volumeMounts:
            - name: ssl-certs
              mountPath: /etc/ssl/certs/ca-bundle.crt
              readOnly: true
          imagePullPolicy: "Always"
      volumes:
        - name: ssl-certs
          hostPath:
            path: "/etc/ssl/certs/ca-bundle.crt"
"""

eks_cluster_aws_auth_string = """- rolearn: arn:aws:iam::002219003547:role/nodes.prod.spell
  username: system:node:{{EC2PrivateDNSName}}
  groups:
  - system:masters
"""

eks_cluster_statsd_sink_yaml = """apiVersion: v1
kind: ConfigMap
metadata:
  name: nginx-graphite-conf
  labels:
    service: statsd-sink
data:
  nginx-graphite-conf: |-
    server {
      listen 81;
      root /opt/graphite/webapp/content;
      index index.html;

      auth_basic           "Spell Metrics - Auth Required";
      auth_basic_user_file /etc/nginx/htpasswd;

      location /media {
        # django admin static files
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/media/;
      }

      location /admin/auth/admin {
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/static/admin;
      }

      location /admin/auth/user/admin {
        alias /usr/local/lib/python2.7/dist-packages/django/contrib/admin/static/admin;
      }

      location / {
        # checks for static file, if not found proxy to app
        try_files \$uri @app;
      }

      location @app {
        include fastcgi_params;
        fastcgi_split_path_info ^()(.*)$;
        fastcgi_pass 127.0.0.1:8080;
        add_header 'Access-Control-Allow-Origin' '*';
        add_header 'Access-Control-Allow-Methods' 'GET, POST, OPTIONS';
        add_header 'Access-Control-Allow-Headers' 'Authorization, Content-Type';
        add_header 'Access-Control-Allow-Credentials' 'true';
      }
    }
---
apiVersion: apps/v1beta1
kind: StatefulSet
metadata:
  labels:
    service: statsd-sink
  name: statsd-sink
spec:
  serviceName: statsd-sink
  selector:
    matchLabels:
      service: statsd-sink
  replicas: 1
  template:
    metadata:
      labels:
        service: statsd-sink
    spec:
      containers:
      - image: hopsoft/graphite-statsd:v0.9.15-phusion0.9.19
        imagePullPolicy: Always
        name: statsd-sink
        ports:
        - containerPort: 8125
          name: metrics-port
          protocol: UDP
        - containerPort: 81
          name: graphite-www
          protocol: TCP
        volumeMounts:
        - name: graphite-storage
          mountPath: /opt/graphite/storage
          subPath: storage
        - name: nginx-graphite-auth-pwd
          mountPath: /etc/nginx/htpasswd
          subPath: htpasswd
          readOnly: true
        - name: nginx-graphite-conf
          mountPath: /etc/nginx/sites-enabled/graphite-statsd.conf
          subPath: graphite-statsd.conf
          readOnly: true
      volumes:
        - name: nginx-graphite-auth-pwd
          secret:
            secretName: nginx-graphite-auth-pwd
            items:
            - key: nginx-graphite-auth-pwd
              path: htpasswd
        - name: nginx-graphite-conf
          configMap:
            name: nginx-graphite-conf
            items:
            - key: nginx-graphite-conf
              path: graphite-statsd.conf
  volumeClaimTemplates:
  - metadata:
      name: graphite-storage
    spec:
      accessModes: [ "ReadWriteOnce" ]
      resources:
        requests:
          storage: 50Gi
---
apiVersion: v1
kind: Service
metadata:
  labels:
    service: statsd-sink
  name: statsd-sink
spec:
  ports:
  - name: statsd-metrics
    port: 8125
    protocol: UDP
    targetPort: 8125
  selector:
    service: statsd-sink
  type: ClusterIP
  clusterIP: None
---
apiVersion: v1
kind: Service
metadata:
  labels:
    service: statsd-sink-graphite
  name: statsd-sink-graphite
  annotations:
    service.beta.kubernetes.io/aws-load-balancer-backend-protocol: http
    service.beta.kubernetes.io/aws-load-balancer-ssl-ports: "443"
    service.beta.kubernetes.io/aws-load-balancer-ssl-cert: >-
      arn:aws:acm:us-west-2:002219003547:certificate/d71ffa58-4723-425e-8cbe-fed3a7a3f6b2
    service.beta.kubernetes.io/aws-load-balancer-cross-zone-load-balancing-enabled: "true"
spec:
  ports:
  - name: graphite-www
    port: 443
    protocol: TCP
    targetPort: 81
  selector:
    service: statsd-sink
  type: LoadBalancer
"""

eks_cluster_ambassador_yaml = """
---
apiVersion: v1
kind: Service
metadata:
  labels:
    app: ambassador
    stack: serving
  name: ambassador
  annotations:
    service.beta.kubernetes.io/aws-load-balancer-backend-protocol: http
    service.beta.kubernetes.io/aws-load-balancer-ssl-ports: "443"
    service.beta.kubernetes.io/aws-load-balancer-ssl-cert: >-
      arn:aws:acm:us-west-2:002219003547:certificate/d71ffa58-4723-425e-8cbe-fed3a7a3f6b2
    service.beta.kubernetes.io/aws-load-balancer-cross-zone-load-balancing-enabled: "true"
    getambassador.io/config: |
      ---
      apiVersion: ambassador/v0
      kind: Module
      name: ambassador
      config:
        x_forwarded_proto_redirect: true
      ---
      apiVersion: ambassador/v0
      kind:  AuthService
      name:  authentication
      auth_service: "https://api.spell.run"
      path_prefix: "/model_server_auth"
spec:
  ports:
  - name: https
    port: 443
    targetPort: 80
  selector:
    app: ambassador
    stack: serving
  type: LoadBalancer
---
apiVersion: v1
kind: Service
metadata:
  labels:
    app: ambassador-admin
    stack: serving
  name: ambassador-admin
spec:
  ports:
  - name: ambassador-admin
    port: 8877
    targetPort: 8877
  selector:
    app: ambassador
    stack: serving
  type: ClusterIP
---
apiVersion: v1
kind: ServiceAccount
metadata:
  name: ambassador
---
apiVersion: apps/v1
kind: Deployment
metadata:
  labels:
    app: ambassador
    stack: serving
  name: ambassador
spec:
  replicas: 2
  selector:
    matchLabels:
      app: ambassador
      stack: serving
  template:
    metadata:
      labels:
        app: ambassador
        stack: serving
    spec:
      containers:
      - env:
        - name: AMBASSADOR_NAMESPACE
          valueFrom:
            fieldRef:
              apiVersion: v1
              fieldPath: metadata.namespace
        - name: AMBASSADOR_SINGLE_NAMESPACE
          value: "true"
        - name: STATSD_ENABLED
          value: "true"
        image: quay.io/datawire/ambassador:0.40.1
        livenessProbe:
          httpGet:
            path: /ambassador/v0/check_alive
            port: 8877
          initialDelaySeconds: 30
          periodSeconds: 30
        name: ambassador
        readinessProbe:
          httpGet:
            path: /ambassador/v0/check_ready
            port: 8877
          initialDelaySeconds: 30
          periodSeconds: 30
        resources:
          limits:
            cpu: 1
            memory: 400Mi
          requests:
            cpu: 200m
            memory: 100Mi
      restartPolicy: Always
      serviceAccountName: ambassador
---
apiVersion: rbac.authorization.k8s.io/v1
kind: Role
metadata:
  name: ambassador
rules:
- apiGroups:
  - ""
  resources:
  - services
  verbs:
  - get
  - list
  - watch
- apiGroups:
  - ""
  resources:
  - configmaps
  verbs:
  - create
  - update
  - patch
  - get
  - list
  - watch
- apiGroups:
  - ""
  resources:
  - secrets
  verbs:
  - get
  - list
  - watch
---
apiVersion: rbac.authorization.k8s.io/v1
kind: RoleBinding
metadata:
  name: ambassador
roleRef:
  apiGroup: rbac.authorization.k8s.io
  kind: Role
  name: ambassador
subjects:
- kind: ServiceAccount
  name: ambassador
"""

eks_cluster_secret_yaml_template = """
apiVersion: v1
kind: Secret
metadata:
  name: s3secret
type: Opaque
stringData:
  AWS_ACCESS_KEY_ID: {}
  AWS_SECRET_ACCESS_KEY: {}
---
apiVersion: v1
kind: Secret
metadata:
  name: nginx-graphite-auth-pwd
type: Opaque
stringData:
  nginx-graphite-auth-pwd: {}
"""


def generate_eks_cluster_autoscaler_yaml(min_nodes, max_nodes, asg_name):
    return eks_cluster_autoscaler_yaml_template.format(min_nodes, max_nodes, asg_name)


def generate_eks_cluster_secret_yaml(aws_access_key, aws_secret_key, ms_auth_pwd):
    return eks_cluster_secret_yaml_template.format(aws_access_key, aws_secret_key, ms_auth_pwd)
